@@ -11,12 +11,8 @@
 #ifndef _HYANTES_INTERPOLATION_H
 #define _HYANTES_INTERPOLATION_H
 #include <stddef.h>
+#include "options.h"
 
-/* interpolation fonction prototype */
-typedef double (*func_interpolation) (double);
-
-/* G_INTER is used to perform smoothing, once set by set_fonc_inter */
-extern /*@null@ */ func_interpolation g_inter;
 
 /* sets global function pointer G_INTER before use */
 extern void set_func_inter(const char *function_name,
