@@ -12,6 +12,7 @@
 #define _HYANTES_MODULE_H
 
 #include "computing.h"
+#include <stdarg.h>
 
 /** 
 * @brief structure containing precomputed values
@@ -29,9 +30,9 @@ typedef struct extra
 */
 struct make_pot_param
 {
-                                          /*@temp@ */ const planartree *ptrees;
+    /*@temp@ */ const planartree *ptrees;
                                           /**< pointer to a valid planartree */
-                                      /*@temp@ */ const extra_t *extra;
+    /*@temp@ */ const extra_t *extra;
                                       /**< pointer to precomuted values of the potential in ptrees, in the same order*/
 };
 
@@ -39,14 +40,21 @@ struct make_pot_param
 /* computes the potential from ITER to ITER+NB_ITER using data from PARAM and fills ITER accordingly */
 #ifdef __cplusplus
 extern "C"
+{
 #endif
-int make_all_pot(hs_potential_t * iter, size_t nb_iter,
-   const struct make_pot_param *param)
+    int make_all_pot(hs_potential_t * iter, size_t nb_iter,
+       const struct make_pot_param *param)
 /*@modifies iter@*/ ;
 
+    int init_module(va_list * ap);
+
+#ifdef __cplusplus
+}
+#endif
+
 extern
 #ifdef __cplusplus
-   "C"
+ "C"
 #endif
 unsigned long get_status();
 
