@@ -40,3 +40,9 @@ int make_all_pot(hs_potential_t * iter, size_t nb_iter,
 {
     return adapt_transform(iter, nb_iter, param, get_processes_max());
 }
+
+
+int init_module(va_list * ap)
+{
+    return ap == NULL ? 1 : 0;
+}
