@@ -13,6 +13,12 @@
 
 static unsigned long count = 0;
 
+int init_module(va_list * ap)
+{
+    return ap == NULL ? 1 : 0;
+}
+
+
 int make_all_pot(hs_potential_t * iter, size_t nb_iter,
    const struct make_pot_param *param)
 {
