@@ -10,7 +10,7 @@
 
 #include "module.h"
 #include "engine.h"
-#include "hs_config.h"
+#include "hs_compat.h"
 
 #include "tbb/task_scheduler_init.h"
 #include "tbb/parallel_for.h"
@@ -57,3 +57,8 @@ int make_all_pot(hs_potential_t * iter, int nb_iter,
        mmpot);
     return 1;
 }
+
+int init_module(va_list * ap)
+{
+    return 0;
+}
